@@ -1,4 +1,4 @@
-#! /bin/sh
+#! /bin/sh -e
 # Licensed to the Apache Software Foundation (ASF) under one or more
 # contributor license agreements.  See the NOTICE file distributed with
 # this work for additional information regarding copyright ownership.
@@ -17,13 +17,13 @@
 # Regenerate the files autoconf / automake
 
 case `uname` in
-      (Darwin)        LIBTOOLIZE=glibtoolize  ;;
-      (*)             LIBTOOLIZE=libtoolize   ;;
+  (Darwin)  LIBTOOLIZE=glibtoolize  ;;
+  (*)       LIBTOOLIZE=libtoolize   ;;
 esac
 $LIBTOOLIZE --force --automake --copy
 
 rm -f config.cache
 rm -f config.log
-aclocal -I .
+aclocal -I src/m4
 autoconf
 automake -a --copy
