@@ -27,18 +27,20 @@ using namespace log4cxx::spi;
 IMPLEMENT_LOG4CXX_OBJECT(OnlyOnceErrorHandler)
 
 OnlyOnceErrorHandler::OnlyOnceErrorHandler() :
- WARN_PREFIX(LOG4CXX_STR("log4cxx warning: ")),
-ERROR_PREFIX(LOG4CXX_STR("log4cxx error: ")), firstTime(true)
+	WARN_PREFIX(LOG4CXX_STR("log4cxx warning: ")),
+	ERROR_PREFIX(LOG4CXX_STR("log4cxx error: ")), firstTime(true)
 {
 }
 
- void OnlyOnceErrorHandler::addRef() const {
-    ObjectImpl::addRef();
- }
+void OnlyOnceErrorHandler::addRef() const
+{
+	ObjectImpl::addRef();
+}
 
- void OnlyOnceErrorHandler::releaseRef() const {
-    ObjectImpl::releaseRef();
- }
+void OnlyOnceErrorHandler::releaseRef() const
+{
+	ObjectImpl::releaseRef();
+}
 
 void OnlyOnceErrorHandler::setLogger(const LoggerPtr&)
 {
@@ -53,29 +55,29 @@ void OnlyOnceErrorHandler::setOption(const LogString&, const LogString&)
 }
 
 void OnlyOnceErrorHandler::error(const LogString& message, const std::exception& e,
-        int) const
+	int) const
 {
-        if(firstTime)
-        {
-                LogLog::error(message, e);
-                firstTime = false;
-        }
+	if (firstTime)
+	{
+		LogLog::error(message, e);
+		firstTime = false;
+	}
 }
 
 void OnlyOnceErrorHandler::error(const LogString& message, const std::exception& e,
-        int errorCode, const log4cxx::spi::LoggingEventPtr&) const
+	int errorCode, const log4cxx::spi::LoggingEventPtr&) const
 {
-        error(message, e, errorCode);
+	error(message, e, errorCode);
 }
 
 
 void OnlyOnceErrorHandler::error(const LogString& message) const
 {
-        if(firstTime)
-        {
-                LogLog::error(message);
-                firstTime = false;
-        }
+	if (firstTime)
+	{
+		LogLog::error(message);
+		firstTime = false;
+	}
 }
 
 
