@@ -23,6 +23,7 @@
 using namespace log4cxx;
 using namespace log4cxx::helpers;
 
-AppenderSkeleton* WriterAppenderTestCase::createAppenderSkeleton() const {
-    return createWriterAppender();
+AppenderSkeleton* WriterAppenderTestCase::createAppenderSkeleton() const
+{
+	return createWriterAppender();
 }
